==> cms-db_v0.7.9.tar.gz: admin/backup_create.php <==
<?php
/*  cms-db  Copyright (C) 2007-2009 Jan Hoffmann
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */
include('checkuser.inc.php');
checkuser('');
include('locale.inc.php');
$locale = new LocalizingClass('backup-action');
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
     "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
	<head>
		<title><?php locale('title_backup-create') ?></title>
		<meta http-equiv="content-type" content="text/html; charset=utf-8" />
		<link rel="stylesheet" type="text/css" href="style.css">
	</head>
	<body>

		<h1><?php locale('title_backup-create') ?></h1>

<?php
$handle = opendir('../data/backup');
while (false !== ($file = readdir ($handle))) {
	if ($file != "." && $file != "..") {
		if (is_file('../data/backup/'.$file)) {
			unlink('../data/backup/'.$file);
		}
	}
}
closedir($handle);

$filename = 'backup_'.date('Ymd').'.cdba';
include('archive.inc.php');
$a = new Archive('cms -db complete backup v0.7.5');
$a->addFolder('../data', '/');
if ($a->getArchive('../data/backup/'.$filename) == false) {
	echo '<p class="error">'.$a->error.'</p>';
} else {
?>
		<p>
			<?php locale('desc_backup-ready') ?>
		</p>
		<p>
			<a class="nonewtab" href="backup_download.php?file=<?php echo $filename ?>&<?php echo SID ?>"><?php locale('link_backup-download') ?></a>
		</p>
		<p>
			<a class="nonewtab" href="backup.php?<?php echo SID ?>"><?php locale('link_back') ?></a>	
		</p>
<?php
}
?>

	</body>
</html>

==> cms-db_v0.8.1.tar.gz: admin/backup_create.php <==
<?php
/*  cms-db  Copyright (C) 2007-2010 Jan Hoffmann
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */

define('cms-db', 'backend');

include('checkuser.inc.php');
checkuser('');
include('locale.inc.php');
$locale = new LocalizingClass('backup-action');
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
     "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
	<head>
		<title><?php locale('title_backup-create') ?></title>
		<meta http-equiv="content-type" content="text/html; charset=utf-8" />
		<link rel="stylesheet" type="text/css" href="style.css">
	</head>
	<body>

		<h1><?php locale('title_backup-create') ?></h1>

<?php
$handle = opendir('../data/backup');
while (false !== ($file = readdir ($handle))) {
	if ($file != "." && $file != "..") {
		if (is_file('../data/backup/'.$file)) {
			unlink('../data/backup/'.$file);
		}
	}
}
closedir($handle);

$filename = 'backup_'.date('Ymd').'.cdba';
include('archive.inc.php');
$a = new Archive('cms -db complete backup v0.7.5');
$a->addFolder('../data', '/');
if ($a->getArchive('../data/backup/'.$filename) == false) {
	echo '<p class="error">'.$a->error.'</p>';
} else {
?>
		<p>
			<?php locale('desc_backup-ready') ?>
		</p>
		<p>
			<a class="nonewtab" href="backup_download.php?file=<?php echo $filename ?>&<?php echo SID; csrf_protection_get_html() ?>"><?php locale('link_backup-download') ?></a>
		</p>
		<p>
			<a class="nonewtab" href="backup.php?<?php echo SID; csrf_protection_get_html() ?>"><?php locale('link_back') ?></a>	
		</p>
<?php
}
?>

	</body>
</html>
